@@ -7,19 +7,22 @@
 
 
 framework_ebp <- function(fixed, pop_data, pop_domains, smp_data, smp_domains,
-                          threshold, custom_indicator = NULL, na.rm, weights) {
+                          threshold, custom_indicator = NULL, na.rm,
+                           weights, aggregate_to = NULL, pop_weights) {
 
   # Reduction of number of variables
   mod_vars <- all.vars(fixed)
   mod_vars <- mod_vars[mod_vars != as.character(fixed[2])]
   smp_vars <- c(as.character(fixed[2]), mod_vars, smp_domains, weights)
-  pop_vars <- c(mod_vars, pop_domains)
+  pop_vars <- c(mod_vars, pop_domains, aggregate_to, pop_weights)
   smp_data <- smp_data[, smp_vars]
   weights <- weights
+  pop_weights <- pop_weights
   fw_check1(
     pop_data = pop_data, mod_vars = mod_vars, pop_domains = pop_domains,
-    smp_data = smp_data, fixed = fixed, smp_domains = smp_domains,
-    threshold = threshold, weights = weights
+    smp_data = smp_data, aggregate_to = aggregate_to, fixed = fixed,
+    smp_domains = smp_domains, threshold = threshold, weights = weights,
+    pop_weights = pop_weights
   )
 
 
@@ -45,9 +48,19 @@ framework_ebp <- function(fixed, pop_data, pop_domains, smp_data, smp_domains,
                                     levels = levels_tmp)
   pop_domains_vec <- pop_data[[pop_domains]]
 
-
   smp_data[[smp_domains]] <- factor(smp_data[[smp_domains]],
                                     levels = levels_tmp)
+
+
+  if(is.null(aggregate_to)){
+    aggregate_to_vec <- NULL
+  }else{
+    levels_tmp <- unique(pop_data[[aggregate_to]])
+    pop_data[[aggregate_to]] <- factor(pop_data[[aggregate_to]],
+                                       levels = levels_tmp)
+    aggregate_to_vec <- pop_data[[aggregate_to]]
+  }
+
   rm(levels_tmp)
   smp_data <- smp_data[order(smp_data[[smp_domains]]), ]
 
@@ -58,7 +71,8 @@ framework_ebp <- function(fixed, pop_data, pop_domains, smp_data, smp_domains,
 
   fw_check2(
     pop_domains = pop_domains, pop_domains_vec = pop_domains_vec,
-    smp_domains = smp_domains, smp_domains_vec = smp_domains_vec
+    smp_domains = smp_domains, smp_domains_vec = smp_domains_vec,
+    aggregate_to = aggregate_to, aggregate_to_vec = aggregate_to_vec
   )
 
 
@@ -70,6 +84,8 @@ framework_ebp <- function(fixed, pop_data, pop_domains, smp_data, smp_domains,
   N_unobs <- N_pop - N_smp
   # Number of domains in the population
   N_dom_pop <- length(unique(pop_domains_vec))
+  # Number of domains in the population on aggregated level
+  N_dom_pop_agg <- length(unique(aggregate_to_vec))
   # Number of domains in the sample
   N_dom_smp <- length(unique(smp_domains_vec))
   # Number of out-of-sample domains
@@ -90,38 +106,41 @@ framework_ebp <- function(fixed, pop_data, pop_domains, smp_data, smp_domains,
   )
 
   indicator_list <- list(
-    fast_mean = function(y, threshold) {
-      t(mean(y))
+    fast_mean = function(y, pop_weights, threshold) {
+      t(weighted.mean(y, pop_weights))
     },
-    hcr = function(y, threshold) {
-      t(mean(y < threshold))
+    hcr = function(y, pop_weights, threshold) {
+       t(weighted.mean(y < threshold, pop_weights))
     },
-    pgap = function(y, threshold) {
-      t(mean((y < threshold) * (threshold - y) / threshold))
+    pgap = function(y, pop_weights, threshold) {
+      sum((1 - (y[y < threshold]/threshold)) * pop_weights[y < threshold])/
+        sum(pop_weights)
     },
-    gini = function(y, threshold) {
-      n <- length(y)
-      y <- sort(y)
-      G <- sum(y * 1L:n)
-      G <- 2 * G / sum(y) - (n + 1L)
-      G <- t(G / n)
-      return(G)
+    gini = function(y, pop_weights, threshold) {
+        n <- length(y)
+        pop_weights <- pop_weights[order(y)]
+        y <- sort(y)
+        auc <- sum((cumsum(c(0, (y * pop_weights)[1:(n-1)])) +
+                      ((y * pop_weights) / 2)) * pop_weights)
+        auc <- (auc / sum(pop_weights)) / sum((y * pop_weights))
+        G <- 1 - (2* auc)
+        return(G)
     },
-    qsr = function(y, threshold) {
-      weights <- rep.int(1, length(y))
-      quant14 <- wtd.quantile(
-        x = y,
-        weights = weights,
-        probs = c(0.2, 0.8)
-      )
+    qsr = function(y, pop_weights, threshold) {
+      quant14 <- wtd.quantile(x = y, weights = pop_weights, probs = c(0.2, 0.8))
 
       iq1 <- y <= quant14[1]
       iq4 <- y > quant14[2]
-      t((sum(weights[iq4] * y[iq4]) / sum(weights[iq4])) /
-        (sum(weights[iq1] * y[iq1]) / sum(weights[iq1])))
+      t((sum(pop_weights[iq4] * y[iq4]) / sum(pop_weights[iq4])) /
+           (sum(pop_weights[iq1] * y[iq1]) / sum(pop_weights[iq1])))
     },
-    quants = function(y, threshold) {
-      t(quantile(y, probs = c(.10, .25, .5, .75, .9)))
+    quants = function(y, pop_weights, threshold) {
+      if(length(unique(pop_weights)) == 1 & 1 %in% unique(pop_weights)){
+        t(quantile(x = y, probs = c(.10, .25, .5, .75, .9)))
+      }else{
+        t(wtd.quantile(x = y, weights = pop_weights,
+                       probs = c(.10, .25, .5, .75, .9)))
+      }
     }
   )
 
@@ -140,6 +159,10 @@ framework_ebp <- function(fixed, pop_data, pop_domains, smp_data, smp_domains,
 
 
   if (!is.null(custom_indicator) && length(custom_indicator) > 0) {
+    for(i in 1:length(custom_indicator)) {
+      formals(custom_indicator[[i]]) <- alist(y=, pop_weights=, threshold=)
+    }
+
     indicator_list <- c(indicator_list, custom_indicator)
     indicator_names <- c(indicator_names, names(custom_indicator))
   }
@@ -159,10 +182,13 @@ framework_ebp <- function(fixed, pop_data, pop_domains, smp_data, smp_domains,
     smp_data = smp_data,
     smp_domains_vec = smp_domains_vec,
     smp_domains = smp_domains,
+    aggregate_to = aggregate_to,
+    aggregate_to_vec = aggregate_to_vec,
     N_pop = N_pop,
     N_smp = N_smp,
     N_unobs = N_unobs,
     N_dom_pop = N_dom_pop,
+    N_dom_pop_agg = N_dom_pop_agg,
     N_dom_smp = N_dom_smp,
     N_dom_unobs = N_dom_unobs,
     n_pop = n_pop,
@@ -172,6 +198,7 @@ framework_ebp <- function(fixed, pop_data, pop_domains, smp_data, smp_domains,
     indicator_list = indicator_list,
     indicator_names = indicator_names,
     threshold = threshold,
-    weights = weights
+    weights = weights,
+    pop_weights = pop_weights
   ))
 }
