@@ -1,36 +1,34 @@
-# Summarizes an emdi direct object
+# Summarizes an emdi Direct Object
 
 #' @export
-#' @importFrom moments skewness kurtosis
-#' @importFrom MuMIn r.squaredGLMM
 #' @rdname emdi_summaries
-
 summary.direct <- function(object, ...) {
   throw_class_error(object, "direct")
-  
+
   call_emdi <- object$call
-  
-  N_dom_smp <-   object$framework$N_dom_smp
-  
+
+  N_dom_smp <- object$framework$N_dom_smp
+
   smp_size <- object$framework$N_smp
-  
+
   smp_size_tab <- table(object$framework$smp_domains_vec)
-  
+
   smp_size_dom <-
     rbind(Sample_domains = summary(as.numeric(smp_size_tab)))
-  
-  sum_emdi <- list(out_of_smp   = NULL,
-                   in_smp       = N_dom_smp,
-                   size_smp     = smp_size,
-                   size_pop     = NULL,
-                   size_dom     = smp_size_dom,
-                   smp_size_tab = smp_size_tab,
-                   transform    = NULL,
-                   normality    = NULL,
-                   icc          = NULL,
-                   coeff_determ = NULL,
-                   model        = NULL,
-                   call         = call_emdi
+
+  sum_emdi <- list(
+    out_of_smp = NULL,
+    in_smp = N_dom_smp,
+    size_smp = smp_size,
+    size_pop = NULL,
+    size_dom = smp_size_dom,
+    smp_size_tab = smp_size_tab,
+    transform = NULL,
+    normality = NULL,
+    icc = NULL,
+    coeff_determ = NULL,
+    model = NULL,
+    call = call_emdi
   )
 
   class(sum_emdi) <- c("summary.direct", "emdi")
@@ -39,9 +37,9 @@ summary.direct <- function(object, ...) {
 
 
 #' @export
-print.summary.direct <- function(x,...) {
+print.summary.direct <- function(x, ...) {
   throw_class_error(x, "direct")
-  
+
   cat("Direct estimation\n")
   cat("\n")
   cat("Call:\n ")
@@ -55,4 +53,4 @@ print.summary.direct <- function(x,...) {
   cat("\n")
   cat("Units in each Domain:")
   print(x$smp_size_tab)
-}
\ No newline at end of file
+}
